==> campaignion_starterkit-7.x-1.3-core.tar.gz: campaignion_starterkit-7.x-1.3/profiles/campaignion_starterkit/modules/campaignion/campaignion_newsletters/src/NewsletterProviderInterface.php <==
<?php
/**
 * @file
 * Abstract base class for email marketing providers
 */

namespace Drupal\campaignion_newsletters;

interface NewsletterProviderInterface {
  public static function fromParameters(array $params);
  /**
   * Fetches current lists from the provider.
   *
   * @return array
   *   An array of Drupal\campaignion_newsletters\NewsletterList objects
   */
  public function getLists();

  /**
   * Fetches current lists of subscribers from the provider.
   *
   * @return array
   *   an array of subscribers.
   */
  public function getSubscribers($list);

  /**
   * Subscribe a user, given a newsletter identifier and email address.
   *
   * @return: True on success.
   */
  public function subscribe($newsletter, $mail, $data, $opt_in = FALSE, $welcome = FALSE);

  /**
   * Subscribe a user, given a newsletter identifier and email address.
   *
   * Should ignore the request if there is no such subscription.
   *
   * @return: True on success.
   */
  public function unsubscribe($newsletter, $mail);

  /**
   * Get additional data for this subscription and a unique fingerprint.
   *
   * @param Subscription $subscription
   *   The subscription object.
   *
   * @return array
   *   An array containing some data object and a fingerprint:
   *   array($data, $fingerprint).
   *   - The $data is passed as $data parameter of subscribe() during
   *     cron runs.
   *   - The $fingerprint must be an sha1-hash. Usually it's a hash
   *     of some subset of $data.
   */
  public function data(Subscription $subscription);
}

==> campaignion_starterkit-7.x-1.5-core.tar.gz: campaignion_starterkit-7.x-1.5/profiles/campaignion_starterkit/modules/campaignion/campaignion_newsletters/src/NewsletterProviderInterface.php <==
<?php
/**
 * @file
 * Abstract base class for email marketing providers
 */

namespace Drupal\campaignion_newsletters;

interface NewsletterProviderInterface {
  public static function fromParameters(array $params);
  /**
   * Fetches current lists from the provider.
   *
   * @return array
   *   An array of Drupal\campaignion_newsletters\NewsletterList objects
   */
  public function getLists();

  /**
   * Fetches current lists of subscribers from the provider.
   *
   * @return array
   *   an array of subscribers.
   */
  public function getSubscribers($list);

  /**
   * Subscribe a user, given a newsletter identifier and email address.
   *
   * @return: True on success.
   */
  public function subscribe(NewsletterList $newsletter, QueueItem $item);

  /**
   * Subscribe a user, given a newsletter identifier and email address.
   *
   * Should ignore the request if there is no such subscription.
   *
   * @return: True on success.
   */
  public function unsubscribe(NewsletterList $newsletter, QueueItem $item);

  /**
   * Get additional data for this subscription and a unique fingerprint.
   *
   * @param Subscription $subscription
   *   The subscription object.
   *
   * @return array
   *   An array containing some data object and a fingerprint:
   *   array($data, $fingerprint).
   *   - The $data is passed as $data parameter of subscribe() during
   *     cron runs.
   *   - The $fingerprint must be an sha1-hash. Usually it's a hash
   *     of some subset of $data.
   */
  public function data(Subscription $subscription);
}
